Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2022-08-10 03:09:11 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2022-08-10 03:09:11 +0300
commit65093195c2c956c73f587ee51cc9fcafe4708e96 (patch)
tree6097e3663d89c7a3f429c6ba752a7661b31b7665 /app/services/system_note_service.rb
parentc03dce2dc9f0f257faac4d43d208d96320ca5c0e (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'app/services/system_note_service.rb')
-rw-r--r--app/services/system_note_service.rb12
1 files changed, 8 insertions, 4 deletions
diff --git a/app/services/system_note_service.rb b/app/services/system_note_service.rb
index 332333d2fc3..9baf749c508 100644
--- a/app/services/system_note_service.rb
+++ b/app/services/system_note_service.rb
@@ -57,7 +57,7 @@ module SystemNoteService
::SystemNotes::IssuablesService.new(noteable: noteable, project: noteable.project, author: user).unrelate_issuable(noteable_ref)
end
# Called when the due_date of a Noteable is changed
#
# noteable - Noteable object
# project - Project owning noteable
@@ -68,11 +68,15 @@ module SystemNoteService
#
# "removed due date"
#
# "changed due date to September 20, 2018"
#
# Returns the created Note object
- def change_due_date(noteable, project, author, due_date)
- ::SystemNotes::TimeTrackingService.new(noteable: noteable, project: project, author: author).change_due_date(due_date)
+ def change_start_date_or_due_date(noteable, project, author, changed_dates)
+ ::SystemNotes::TimeTrackingService.new(
+ noteable: noteable,
+ project: project,
+ author: author
+ ).change_start_date_or_due_date(changed_dates)
end
# Called when the estimated time of a Noteable is changed
@@ -57,7 +57,7 @@ module SystemNoteService
::SystemNotes::IssuablesService.new(noteable: noteable, project: noteable.project, author: user).unrelate_issuable(noteable_ref)
end
- # Called when the due_date of a Noteable is changed
+ # Called when the due_date or start_date of a Noteable is changed
#
# noteable - Noteable object
@@ -68,11 +68,15 @@ module SystemNoteService
# "removed due date"
#
- # "changed due date to September 20, 2018"
+ # "changed due date to September 20, 2018 and changed start date to September 25, 2018"
#
# Returns the created Note object